# puckdns
[![codecov](https://codecov.io/gh/Snake-Whisper/puckdns/branch/master/graph/badge.svg?token=7R83F1FHXO)](https://codecov.io/gh/Snake-Whisper/puckdns)

Python API for the great free DNS Service "PUCK" (http://puck.nether.net/dns)

---
 
 ## Documentation
 Please read the documentation at https://puckdns.readthedocs.io